pub struct TwoFactorDuoDetails {
pub enabled: Option<bool>,
pub host: Option<String>,
pub client_id: Option<String>,
pub client_secret: Option<String>,
}Expand description
TwoFactorDuoDetails : Duo provider details for both user and organization scopes. Hydrated from
Bit.Core.Entities.User or Bit.Core.AdminConsole.Entities.Organization; embedded by the
per-action TwoFactorDuo*ResponseModel / TwoFactorOrganizationDuo*ResponseModel wrappers.
Fields
enabled: Option<bool>host: Option<String>client_id: Option<String>client_secret: Option<String>Implementations
Sourceimpl TwoFactorDuoDetails
impl TwoFactorDuoDetails
Sourcepub fn new() -> TwoFactorDuoDetails
pub fn new() -> TwoFactorDuoDetails
Duo provider details for both user and organization scopes. Hydrated from
Bit.Core.Entities.User or Bit.Core.AdminConsole.Entities.Organization; embedded by the
per-action TwoFactorDuo*ResponseModel / TwoFactorOrganizationDuo*ResponseModel wrappers.